@@ -86,7 +86,7 @@ void BatchRenderer::registerAnimator(LottieAnimation *animator)
     entry->currentFrame = animator->startFrame();
     entry->animDir = animator->direction();
     entry->bmTreeBlueprint = new BMBase;
-    parse(entry->bmTreeBlueprint, animator->jsonSource());
+    parse(entry->bmTreeBlueprint, animator->jsonSource(), animator->version());
     m_waitCondition.wakeAll();
 }
 
@@ -125,18 +125,36 @@ bool BatchRenderer::gotoFrame(LottieAnimation *animator, int frame)
 
 void BatchRenderer::pruneFrameCache(Entry* e)
 {
+    QHash<int, BMBase*>::iterator removeCandidate = e->frameCache.end();
+    if (e->frameCache.size() == m_cacheSize &&
+            !e->frameCache.contains(e->currentFrame))
+        removeCandidate = e->frameCache.begin();
+
     QHash<int, BMBase*>::iterator it = e->frameCache.begin();
     while (it != e->frameCache.end()) {
         int frame = it.key();
         if ((frame - e->currentFrame) * e->animDir >= 0) { // same frame or same direction
+            if (removeCandidate != e->frameCache.end() &&
+                    (removeCandidate.key() - frame) * e->animDir < 0)
+                removeCandidate = it;
             ++it;
         } else {
             qCDebug(lcLottieQtBodymovinRenderThread) << "Animator:" << static_cast<void*>(e->animator)
                                                      << "Remove frame from cache" << frame;
             delete it.value();
             it = e->frameCache.erase(it);
+            removeCandidate = e->frameCache.end();
         }
     }
+    if (removeCandidate != e->frameCache.end()) {
+        qCDebug(lcLottieQtBodymovinRenderThread) << "Animator:"
+                                                 << static_cast<void*>(e->animator)
+                                                 << "Remove frame from cache"
+                                                 << removeCandidate.key()
+                                                 << "(Reason - cache is full)";
+        e->frameCache.erase(removeCandidate);
+    }
+    m_lastRenderedFrame = -1;
 }
 
 BMBase *BatchRenderer::getFrame(LottieAnimation *animator, int frameNumber)
@@ -153,6 +171,9 @@ BMBase *BatchRenderer::getFrame(LottieAnimation *animator, int frameNumber)
 void BatchRenderer::prerender(Entry *animEntry)
 {
     while (animEntry->frameCache.size() < m_cacheSize) {
+        if (m_lastRenderedFrame == animEntry->currentFrame)
+            animEntry->currentFrame += animEntry->animDir;
+
         BMBase *&bmTree = animEntry->frameCache[animEntry->currentFrame];
         if (bmTree == nullptr) {
             bmTree = new BMBase(*animEntry->bmTreeBlueprint);
@@ -193,6 +214,7 @@ void BatchRenderer::frameRendered(LottieAnimation *animator, int frameNumber)
             delete root;
             m_waitCondition.wakeAll();
         }
+        m_lastRenderedFrame = frameNumber;
     }
 }
 
@@ -210,7 +232,8 @@ void BatchRenderer::run()
     }
 }
 
-int BatchRenderer::parse(BMBase *rootElement, const QByteArray &jsonSource) const
+int BatchRenderer::parse(BMBase *rootElement, const QByteArray &jsonSource,
+                         const QVersionNumber &version) const
 {
     QJsonDocument doc = QJsonDocument::fromJson(jsonSource);
     QJsonObject rootObj = doc.object();
@@ -239,14 +262,14 @@ int BatchRenderer::parse(BMBase *rootElement, const QByteArray &jsonSource) cons
             QString refId = jsonLayer.value("refId").toString();
             jsonLayer.insert("asset", assets.value(refId));
         }
-        BMLayer *layer = BMLayer::construct(jsonLayer);
+        BMLayer *layer = BMLayer::construct(jsonLayer, version);
         if (layer) {
             layer->setParent(rootElement);
             // Mask layers must be rendered before the layers they affect to
-            // although they appear before in layer hierarchy. For this reason
-            // move a mask after the affected layers, so it will be rendered first
+            // although they appear after in layer hierarchy. For this reason
+            // move a mask in front of the affected layer, so it will be rendered first
             if (layer->isMaskLayer())
-                rootElement->prependChild(layer);
+                rootElement->insertChildBeforeLast(layer);
             else
                 rootElement->appendChild(layer);
         }
